@@ -1,3 +1,8 @@
+# Copyright (C) 2022 The Software Heritage developers
+# See the AUTHORS file at the top-level directory of this distribution
+# License: GNU General Public License version 3, or any later version
+# See top-level LICENSE file for more information
+
 # import pkg_resources
 import os
 from pathlib import Path
@@ -28,9 +33,8 @@ schema = make_executable_schema(
     resolvers.branch_target,
     resolvers.release_target,
     resolvers.directory_entry_target,
+    resolvers.binary_string,
     scalars.id_scalar,
-    scalars.string_scalar,
     scalars.datetime_scalar,
     scalars.swhid_scalar,
-    scalars.hash_value_scalar,
 )
