@@ -1,3 +1,8 @@
+# Copyright (C) 2022 The Software Heritage developers
+# See the AUTHORS file at the top-level directory of this distribution
+# License: GNU General Public License version 3, or any later version
+# See top-level LICENSE file for more information
+
 from datetime import datetime
 
 from ariadne import ScalarType
@@ -8,9 +13,7 @@ from swh.model.swhids import CoreSWHID
 
 datetime_scalar = ScalarType("DateTime")
 swhid_scalar = ScalarType("SWHID")
-hash_value_scalar = ScalarType("HashValue")
 id_scalar = ScalarType("ID")
-string_scalar = ScalarType("String")
 
 
 @id_scalar.serializer
@@ -20,18 +23,6 @@ def serialize_id(value):
     return value
 
 
-@string_scalar.serializer
-def serialize_string(value):
-    if type(value) is bytes:
-        return value.decode("utf-8")
-    return value
-
-
-@hash_value_scalar.serializer
-def serialize_hash_value(value):
-    return value.hex()
-
-
 @datetime_scalar.serializer
 def serialize_datetime(value):
     # FIXME, handle error and return None
