@@ -1,29 +1,33 @@
+# Copyright (C) 2022 The Software Heritage developers
+# See the AUTHORS file at the top-level directory of this distribution
+# License: GNU General Public License version 3, or any later version
+# See top-level LICENSE file for more information
+
 import base64
 from datetime import datetime
-from typing import List
+from typing import List, Optional
 
 from swh.storage.interface import PagedResult
 
-
-def b64encode(text: str) -> str:
-    return base64.b64encode(bytes(text, "utf-8")).decode("utf-8")
+ENCODING = "utf-8"
 
 
-def get_encoded_cursor(cursor: str) -> str:
+def get_b64_string(source) -> str:
+    if type(source) is str:
+        source = source.encode(ENCODING)
+    return base64.b64encode(source).decode("ascii")
+
+
+def get_encoded_cursor(cursor: Optional[str]) -> Optional[str]:
     if cursor is None:
         return None
-    return b64encode(cursor)
+    return get_b64_string(cursor)
 
 
 def get_decoded_cursor(cursor: str) -> str:
     if cursor is None:
         return None
-    return base64.b64decode(cursor).decode("utf-8")
-
-
-def str_to_sha1(sha1: str) -> bytearray:
-    # FIXME, use core function
-    return bytearray.fromhex(sha1)
+    return base64.b64decode(cursor, validate=True).decode()
 
 
 def get_formatted_date(date: datetime) -> str:
